@@ -65,7 +65,7 @@ class Actor:
             monochrome_color: A color that you'd like to paint actors with. Color here
                 is a tuple of three decimal values representing R,G, and B.
         """
-        if _validate_input(monochrome_color, float, max_val=1.0):
+        if _validate_input(monochrome_color, [float], max_val=1.0):
             self._monochrome_color = monochrome_color
         else:
             raise ValueError(
@@ -95,9 +95,8 @@ class Actor:
             mapper.SetScalarModeToUsePointData()
             mapper.SetScalarVisibility(True)
 
-            range_min, range_max = field_info.legend_parameter.range
-            mapper.SetScalarRange(range_min, range_max)
             mapper.SetLookupTable(field_info.legend_parameter.get_lookuptable())
+            mapper.SetScalarRange(field_info.legend_parameter.range)
             mapper.Update()
 
         actor = vtk.vtkActor()
@@ -115,6 +114,10 @@ class Actor:
         if self._modeldataset.display_mode == DisplayMode.Wireframe:
             actor.GetProperty().SetRepresentationToWireframe()
 
+        # This is import for grids with sensor points instead of meshes
+        elif self._modeldataset.display_mode == DisplayMode.Points:
+            actor.GetProperty().SetPointSize(15)
+
         return actor
 
     @classmethod
